@@ -979,12 +979,11 @@ class TabSqliteDb:
         '''
         maximum_number_of_candidates = 100
         engine_name = os.path.basename(self.filename).replace('.db', '')
+        code_point_function: Callable[[str], bytes] = lambda x: (b'\xff\xff')
         if engine_name in [
                 'cangjie3', 'cangjie5', 'cangjie-big',
                 'quick-classic', 'quick3', 'quick5']:
-            code_point_function: Callable[[str], bytes] = self.big5_code
-        else:
-            code_point_function: Callable[[str], bytes] = lambda x: (b'\xff\xff')
+            code_point_function = self.big5_code
         if self._is_chinese:
             pinyin_exact_match_function: Callable[[str], int] = lambda x: (
                 - int(typed_tabkeys == x[:-1] and  x[-1] in '!@#$%')
@@ -1207,12 +1206,11 @@ class TabSqliteDb:
         maximum_number_of_candidates = 100
         engine_name = os.path.basename(self.filename).replace('.db', '')
 
+        code_point_function: Callable[[str], bytes] = lambda x: (b'\xff\xff')
         if engine_name in [
                 'cangjie3', 'cangjie5', 'cangjie-big',
                 'quick-classic', 'quick3', 'quick5']:
-            code_point_function: Callable[[str], bytes] = self.big5_code
-        else:
-            code_point_function: Callable[[str], bytes] = lambda x: (b'\xff\xff')
+            code_point_function = self.big5_code
 
         return sorted(candidates,
                       key=lambda x: (
@@ -1490,7 +1488,7 @@ class TabSqliteDb:
         if self._is_chinese and phrase in CHINESE_NOCHECK_CHARS:
             return
         if not dynamic_adjust:
-            if not self.user_can_define_phrase or not self.is_chinese:
+            if not self.user_can_define_phrase or not self._is_chinese:
                 return
             tabkeys = self.parse_phrase(phrase)
             if not tabkeys:
@@ -1518,7 +1516,7 @@ class TabSqliteDb:
                         tabkeys=tabkeys, phrase=phrase, freq=0, user_freq=1,
                         database='user_db')
             else:
-                if not self.user_can_define_phrase or not self.is_chinese:
+                if not self.user_can_define_phrase or not self._is_chinese:
                     return
                 tabkeys = self.parse_phrase(phrase)
                 if not tabkeys:
